Class: Kentico::Kontent::Delivery::QueryParameters::Filter

Inherits:
ParameterBase
  • Object
show all
Defined in:
lib/delivery/query_parameters/filters.rb

Overview

Provides the base class for filter implementations. See https://developer.kenticocloud.com/v1/reference#content-filtering

Constant Summary

Constants inherited from ParameterBase

ParameterBase::SEPARATOR

Instance Attribute Summary

Attributes inherited from ParameterBase

#key

Instance Method Summary collapse

Methods inherited from ParameterBase

#provide_query_string_parameter

Constructor Details

#initialize(key, operator, values, eq_sign = true) ⇒ Filter

Constructor.

  • Args:
    • key (+string+) The field to filter upon
    • operator (+string+) The Kentico Kontent filter being applied to the field, in brackets
    • values (+Object+) One or more values which will appear as the value of the query string parameter
    • eq_sign (+boolean+) If false, the equals sign is not generated in the parameter


17
18
19
# File 'lib/delivery/query_parameters/filters.rb', line 17

def initialize(key, operator, values, eq_sign = true)
  super(key, operator, values, eq_sign)
end